==> nomadic_2025_01_17.zip: nomadic/resources/views/frontend/guest/guest-data.blade.php <==
<div class="row ps-3 pe-3">
  <div class="col-md-12 text-center imagecard">
    @if($data->profile_pic)
    <img src="{{asset('storage/profile-pic')}}/{{$data->profile_pic}}" class="img-fluid" width="200" height="200">
    @else
    <img src="{{asset('images/user-img.png')}}" class="img-fluid" width="200" height="200">
    @endif
  </div>
</div>

<div class="row mt-3 ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Name</label>
    <div class="clearboth"></div>
    <span class="timename"><b>{{ucfirst($data->fname)}} {{ucfirst($data->lname)}}</b></span>
  </div>
</div>

<div class="row ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Email</label>
    <div class="clearboth"></div>
    <span class="timename"><b>{{$data->email}}</b></span>
  </div>
</div>

<div class="row ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Location</label>
    <div class="clearboth"></div>
    <span class="timeloc"><b>{{ucfirst($data->location->location)}}</b></span>
  </div>
</div>

<div class="row ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Date</label>
    <div class="clearboth"></div>
    <span class="timecard"><b>{{($data->invitation_date)}} {{($data->invitation_time)}}</b></span>  
  </div>
</div>


<div class="row mt-3 mb-3 ps-3 pe-3">
  <div class="col-md-12 text-center">
    @if($data->status==1)
    <b>CheckedIn</b>
    @elseif($data->status==2)
    <b>Cancelled</b>
    @else
      <input type="button" class="btn btn-danger guestaction" value="{{__('Cancel')}}" data-status="2" data-id="{{$data->id}}"/>
      @if(auth()->user()->uuid!=$data->guest_uuid)
      <input type="button" class="btn btn-dark ms-3 guestaction" value="{{__('Resend')}}" data-status="3" data-id="{{$data->id}}"/>
      @endif
    @endif
  </div>
</div>

@if(auth()->user()->uuid==$data->guest_uuid)
<div class="col-md-12 bkginv text-center pt-3 pb-3">
{!! QrCode::size(150)->generate(url('/backend/upcoming-guests/'.$data->location_id).'/'.$data->id) !!}
</div>
@endif

==> nomadic_2025_07_19.zip: nomadic/resources/views/frontend/guest/guest-data.blade.php <==
<div class="row ps-3 pe-3">
  <div class="col-md-12 text-center imagecard">
    @if($data->profile_pic)
    <img src="{{asset('storage/profile-pic')}}/{{$data->profile_pic}}" class="img-fluid" width="200" height="200">
    @else
    <img src="{{asset('images/user-img.png')}}" class="img-fluid" width="200" height="200">
    @endif
  </div>
</div>

<div class="row mt-3 ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Name</label>
    <div class="clearboth"></div>
    <span class="timename"><b>{{ucfirst($data->fname)}} {{ucfirst($data->lname)}}</b></span>
  </div>
</div>

<div class="row ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Email</label>
    <div class="clearboth"></div>
    <span class="timename"><b>{{$data->email}}</b></span>
  </div>
</div>

<div class="row ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Location</label>
    <div class="clearboth"></div>
    <span class="timeloc"><b>{{ucfirst($data->location->location)}}</b></span>
  </div>
</div>

<div class="row ps-3 pe-3">
  <div class="col-md-12">
    <label class="small1">Date</label>
    <div class="clearboth"></div>
    <span class="timecard"><b>{{($data->invitation_date)}} {{($data->invitation_time)}}</b></span>  
  </div>
</div>


<div class="row mt-3 mb-3 ps-3 pe-3">
  <div class="col-md-12 text-center">
    @if($data->status==1)
    <span class="badge badge-success" style="color:#000000;">CheckedIn</span> 
    @elseif($data->status==2)
    <span class="badge badge-danger" style="color:#FF0000;">Cancelled</span>
    @elseif($data->status==3)
    <span class="badge badge-success" style="color:#000000;"> @if(empty($data->comp)) Free @else Paid @endif</span>
    @else
      @if(!empty($data->comp))
      <input type="button" class="btn btn-danger goingevent" value="{{__('Make Payment')}}" data-event="{{$data->ref_id}}" data-guest="{{$data->id}}"/>&nbsp;  
      @endif
      <input type="button" class="btn btn-danger guestaction" value="{{__('Cancel')}}" data-status="2" data-id="{{$data->id}}"/>&nbsp;
      @if(auth()->user()->uuid!=$data->guest_uuid)
      <input type="button" class="btn btn-dark ms-3 guestaction" style="color:#FFFFFF;" value="{{__('Resend')}}" data-status="3" data-id="{{$data->id}}"/>
      @endif
    @endif
  </div>
</div>

@if(auth()->user()->uuid==$data->guest_uuid)
<div class="col-md-12 bkginv text-center pt-3 pb-3">
{!! QrCode::size(150)->generate(url('guest-detail/'.$data->id)) !!}
</div>
@endif
